@@ -349,7 +349,7 @@ typedef struct {
   EphyEmbedShell *shell;
   char *origin;
   gint32 promise_id;
-  gint32 page_id;
+  guint64 page_id;
 } PasswordManagerData;
 
 static void
@@ -370,7 +370,7 @@ password_manager_query_finished_cb (GList               *records,
                                                                                    data->page_id,
                                                                                    data->origin);
   if (proxy)
-    ephy_web_extension_proxy_password_query_response (proxy, username, password, data->promise_id);
+    ephy_web_extension_proxy_password_query_response (proxy, username, password, data->promise_id, data->page_id);
 
   g_object_unref (data->shell);
   g_free (data->origin);
@@ -395,6 +395,14 @@ property_to_int32 (JSCValue   *value,
   return jsc_value_to_int32 (prop);
 }
 
+static int
+property_to_uint64 (JSCValue   *value,
+                    const char *name)
+{
+  g_autoptr(JSCValue) prop = jsc_value_object_get_property (value, name);
+  return (guint64)jsc_value_to_double (prop);
+}
+
 static void
 web_extension_password_manager_query_received_cb (WebKitUserContentManager *manager,
                                                   WebKitJavascriptResult   *message,
@@ -408,7 +416,7 @@ web_extension_password_manager_query_received_cb (WebKitUserContentManager *mana
   g_autofree char *username_field = property_to_string_or_null (value, "usernameField");
   g_autofree char *password_field = property_to_string_or_null (value, "passwordField");
   gint32 promise_id = property_to_int32 (value, "promiseID");
-  gint32 page_id = property_to_int32 (value, "pageID");
+  guint64 page_id = property_to_uint64 (value, "pageID");
 
   PasswordManagerData *data = g_new (PasswordManagerData, 1);
   data->shell = g_object_ref (shell);
@@ -483,7 +491,7 @@ web_extension_password_manager_save_real (EphyEmbedShell *shell,
   g_autofree char *password_field = property_to_string_or_null (value, "passwordField");
   g_autoptr(JSCValue) is_new_prop = jsc_value_object_get_property (value, "isNew");
   gboolean is_new = jsc_value_to_boolean (is_new_prop);
-  gint32 page_id = property_to_int32 (value, "pageID");
+  guint64 page_id = property_to_uint64 (value, "pageID");
   EphyWebView *view;
 
   /* Both password and password field are required. */
@@ -491,12 +499,12 @@ web_extension_password_manager_save_real (EphyEmbedShell *shell,
     return;
 
   /* The username field is required if username is present. */
-  if (username != NULL && username_field == NULL)
-    g_clear_pointer (&username_field, g_free);
+  if (username && !username_field)
+    g_clear_pointer (&username, g_free);
 
   /* The username is required if username field is present. */
-  if (username == NULL && username_field != NULL)
-    g_clear_pointer (&username, g_free);
+  if (!username && username_field)
+    g_clear_pointer (&username_field, g_free);
 
   /* This also sanity checks that a page isn't saving websites for
    * other origins. Remember the request comes from the untrusted web
@@ -553,9 +561,9 @@ web_extension_password_manager_cached_users_received_cb (WebKitUserContentManage
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
 
   JSCValue *value = webkit_javascript_result_get_js_value (message);
-  g_autofree char *origin = jsc_value_to_string (jsc_value_object_get_property (value, "origin"));
-  gint32 promise_id = jsc_value_to_int32 (jsc_value_object_get_property (value, "promiseID"));
-  gint32 page_id = jsc_value_to_int32 (jsc_value_object_get_property (value, "pageID"));
+  g_autofree char *origin = property_to_string_or_null (value, "origin");
+  gint32 promise_id = property_to_int32 (value, "promiseID");
+  guint64 page_id = property_to_uint64 (value, "pageID");
 
   GList *cached_users;
   cached_users = ephy_password_manager_get_cached_users (priv->password_manager, origin);
@@ -563,7 +571,7 @@ web_extension_password_manager_cached_users_received_cb (WebKitUserContentManage
   EphyWebExtensionProxy *proxy = ephy_embed_shell_get_extension_proxy_for_page_id (
                                     shell, page_id, origin);
   if (proxy)
-    ephy_web_extension_proxy_password_cached_users_response (proxy, cached_users, promise_id);
+    ephy_web_extension_proxy_password_cached_users_response (proxy, cached_users, promise_id, page_id);
 }
 
 static void
@@ -762,7 +770,7 @@ ephy_embed_shell_get_global_history_service (EphyEmbedShell *shell)
     else
       mode = EPHY_SQLITE_CONNECTION_MODE_READWRITE;
 
-    filename = g_build_filename (ephy_dot_dir (), EPHY_HISTORY_FILE, NULL);
+    filename = g_build_filename (ephy_profile_dir (), EPHY_HISTORY_FILE, NULL);
     priv->global_history_service = ephy_history_service_new (filename, mode);
     g_free (filename);
     g_assert (priv->global_history_service);
@@ -801,16 +809,13 @@ ephy_embed_shell_get_global_gsb_service (EphyEmbedShell *shell)
 
   if (priv->global_gsb_service == NULL) {
     char *api_key;
-    char *dot_dir;
     char *db_path;
 
     api_key = g_settings_get_string (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_GSB_API_KEY);
-    dot_dir = ephy_default_dot_dir ();
-    db_path = g_build_filename (dot_dir, EPHY_GSB_FILE, NULL);
+    db_path = g_build_filename (ephy_default_cache_dir (), EPHY_GSB_FILE, NULL);
     priv->global_gsb_service = ephy_gsb_service_new (api_key, db_path);
 
     g_free (api_key);
-    g_free (dot_dir);
     g_free (db_path);
   }
 
@@ -961,10 +966,10 @@ initialize_web_extensions (WebKitWebContext *web_context,
 
   private_profile = priv->mode == EPHY_EMBED_SHELL_MODE_PRIVATE || priv->mode == EPHY_EMBED_SHELL_MODE_INCOGNITO || priv->mode == EPHY_EMBED_SHELL_MODE_AUTOMATION;
   browser_mode = priv->mode == EPHY_EMBED_SHELL_MODE_BROWSER;
-  user_data = g_variant_new ("(smsssbb)",
+  user_data = g_variant_new ("(smsmssbb)",
                              priv->guid,
                              address,
-                             ephy_dot_dir (),
+                             ephy_profile_dir_is_default () ? NULL : ephy_profile_dir (),
                              ephy_filters_manager_get_adblock_filters_dir (priv->filters_manager),
                              private_profile,
                              browser_mode);
@@ -1094,8 +1099,6 @@ ephy_embed_shell_create_web_context (EphyEmbedShell *shell)
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   WebKitWebsiteDataManager *manager;
-  char *data_dir;
-  char *cache_dir;
 
   if (priv->mode == EPHY_EMBED_SHELL_MODE_INCOGNITO) {
     priv->web_context = webkit_web_context_new_ephemeral ();
@@ -1108,18 +1111,9 @@ ephy_embed_shell_create_web_context (EphyEmbedShell *shell)
     return;
   }
 
-  data_dir = g_build_filename (priv->mode == EPHY_EMBED_SHELL_MODE_PRIVATE ?
-                               ephy_dot_dir () : g_get_user_data_dir (),
-                               g_get_prgname (), NULL);
-  cache_dir = g_build_filename (priv->mode == EPHY_EMBED_SHELL_MODE_PRIVATE ?
-                                ephy_dot_dir () : g_get_user_cache_dir (),
-                                g_get_prgname (), NULL);
-
-  manager = webkit_website_data_manager_new ("base-data-directory", data_dir,
-                                             "base-cache-directory", cache_dir,
+  manager = webkit_website_data_manager_new ("base-data-directory", ephy_profile_dir (),
+                                             "base-cache-directory", ephy_cache_dir (),
                                              NULL);
-  g_free (data_dir);
-  g_free (cache_dir);
 
   priv->web_context = webkit_web_context_new_with_website_data_manager (manager);
   g_object_unref (manager);
@@ -1128,18 +1122,7 @@ ephy_embed_shell_create_web_context (EphyEmbedShell *shell)
 static char *
 adblock_filters_dir (EphyEmbedShell *shell)
 {
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-  char *result;
-
-  if (priv->mode == EPHY_EMBED_SHELL_MODE_APPLICATION) {
-    char *default_dot_dir = ephy_default_dot_dir ();
-
-    result = g_build_filename (default_dot_dir, "adblock", NULL);
-    g_free (default_dot_dir);
-  } else
-    result = g_build_filename (ephy_dot_dir (), "adblock", NULL);
-
-  return result;
+  return g_build_filename (ephy_cache_dir (), "adblock", NULL);
 }
 
 static void
@@ -1149,8 +1132,6 @@ download_started_cb (WebKitWebContext *web_context,
 {
   EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
   EphyDownload *ephy_download;
-  EphyEmbed *embed;
-  GtkWindow *window;
   gboolean ephy_download_set;
 
   /* Is download locked down? */
@@ -1170,12 +1151,6 @@ download_started_cb (WebKitWebContext *web_context,
     return;
 
   ephy_download = ephy_download_new (download);
-
-  window = gtk_application_get_active_window (GTK_APPLICATION (shell));
-  embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
-  if (embed != NULL)
-    ephy_embed_download_started (embed, ephy_download);
-
   ephy_downloads_manager_add_download (priv->downloads_manager, ephy_download);
   g_object_unref (ephy_download);
 }
@@ -1278,10 +1253,7 @@ ephy_embed_shell_startup (GApplication *application)
    */
   if (priv->mode != EPHY_EMBED_SHELL_MODE_AUTOMATION) {
     /* Favicon Database */
-    if (priv->mode == EPHY_EMBED_SHELL_MODE_PRIVATE)
-      favicon_db_path = g_build_filename (ephy_dot_dir (), "icondatabase", NULL);
-    else
-      favicon_db_path = g_build_filename (g_get_user_cache_dir (), "epiphany", "icondatabase", NULL);
+    favicon_db_path = g_build_filename (ephy_cache_dir (), "icondatabase", NULL);
     webkit_web_context_set_favicon_database_directory (priv->web_context, favicon_db_path);
     g_free (favicon_db_path);
 
@@ -1319,7 +1291,7 @@ ephy_embed_shell_startup (GApplication *application)
   /* Store cookies in moz-compatible SQLite format */
   cookie_manager = webkit_web_context_get_cookie_manager (priv->web_context);
   if (!webkit_web_context_is_ephemeral (priv->web_context)) {
-    filename = g_build_filename (ephy_dot_dir (), "cookies.sqlite", NULL);
+    filename = g_build_filename (ephy_profile_dir (), "cookies.sqlite", NULL);
     webkit_cookie_manager_set_persistent_storage (cookie_manager, filename,
                                                   WEBKIT_COOKIE_PERSISTENT_STORAGE_SQLITE);
     g_free (filename);
@@ -1601,7 +1573,7 @@ ephy_embed_shell_set_page_setup (EphyEmbedShell *shell,
 
   priv->page_setup = page_setup;
 
-  path = g_build_filename (ephy_dot_dir (), PAGE_SETUP_FILENAME, NULL);
+  path = g_build_filename (ephy_profile_dir (), PAGE_SETUP_FILENAME, NULL);
   gtk_page_setup_to_file (page_setup, path, NULL);
   g_free (path);
 }
@@ -1622,7 +1594,7 @@ ephy_embed_shell_get_page_setup (EphyEmbedShell *shell)
     GError *error = NULL;
     char *path;
 
-    path = g_build_filename (ephy_dot_dir (), PAGE_SETUP_FILENAME, NULL);
+    path = g_build_filename (ephy_profile_dir (), PAGE_SETUP_FILENAME, NULL);
     priv->page_setup = gtk_page_setup_new_from_file (path, &error);
     g_free (path);
 
@@ -1662,7 +1634,7 @@ ephy_embed_shell_set_print_settings (EphyEmbedShell   *shell,
 
   priv->print_settings = settings ? settings : gtk_print_settings_new ();
 
-  path = g_build_filename (ephy_dot_dir (), PRINT_SETTINGS_FILENAME, NULL);
+  path = g_build_filename (ephy_profile_dir (), PRINT_SETTINGS_FILENAME, NULL);
   gtk_print_settings_to_file (settings, path, NULL);
   g_free (path);
 }
@@ -1686,7 +1658,7 @@ ephy_embed_shell_get_print_settings (EphyEmbedShell *shell)
     GError *error = NULL;
     char *path;
 
-    path = g_build_filename (ephy_dot_dir (), PRINT_SETTINGS_FILENAME, NULL);
+    path = g_build_filename (ephy_profile_dir (), PRINT_SETTINGS_FILENAME, NULL);
     priv->print_settings = gtk_print_settings_new_from_file (path, &error);
     g_free (path);
 
@@ -1717,53 +1689,6 @@ ephy_embed_shell_get_mode (EphyEmbedShell *shell)
   return priv->mode;
 }
 
-/**
- * ephy_embed_shell_launch_handler:
- * @shell: an #EphyEmbedShell
- * @file: a #GFile to open
- * @mime_type: the mime type of @file or %NULL
- * @user_time: user time to prevent focus stealing
- *
- * Tries to open @file with the right application, making sure we will
- * not call ourselves in the process. This is needed to avoid
- * potential infinite loops when opening unknown file types.
- *
- * Returns: %TRUE on success
- **/
-gboolean
-ephy_embed_shell_launch_handler (EphyEmbedShell *shell,
-                                 GFile          *file,
-                                 const char     *mime_type,
-                                 guint32         user_time)
-{
-  GAppInfo *app;
-  GList *list = NULL;
-  gboolean ret = FALSE;
-
-  g_assert (EPHY_IS_EMBED_SHELL (shell));
-  g_assert (file);
-
-  if (mime_type == NULL)
-    return ret;
-
-  if (ephy_is_running_inside_flatpak ()) {
-    return ephy_file_launch_file_via_uri_handler (file);
-  }
-
-  app = ephy_file_launcher_get_app_info_for_file (file, mime_type);
-
-  /* Do not allow recursive calls into the browser, they can lead to
-   * infinite loops and they should never happen anyway. */
-  if (!app || g_strcmp0 (g_app_info_get_id (app), "org.gnome.Epiphany.desktop") == 0)
-    return ret;
-
-  list = g_list_append (list, file);
-  ret = ephy_file_launch_application (app, list, user_time, NULL);
-  g_list_free (list);
-
-  return ret;
-}
-
 /**
  * ephy_embed_shell_clear_cache:
  * @shell: an #EphyEmbedShell
