@@ -69,17 +69,17 @@ test_web_app_lifetime (void)
     /* Test creation */
     id = ephy_web_application_get_app_id_from_name (test.name);
     desktop_file = ephy_web_application_create (id, test.url, test.name, NULL);
-    g_assert (g_str_has_prefix (desktop_file, ephy_dot_dir ()));
-    g_assert (g_file_test (desktop_file, G_FILE_TEST_EXISTS));
+    g_assert_true (g_str_has_prefix (desktop_file, ephy_profile_dir ()));
+    g_assert_true (g_file_test (desktop_file, G_FILE_TEST_EXISTS));
 
     /* Test the desktop file */
     key_file = g_key_file_new ();
-    g_assert (g_key_file_load_from_file (key_file, desktop_file, G_KEY_FILE_NONE, NULL));
+    g_assert_true (g_key_file_load_from_file (key_file, desktop_file, G_KEY_FILE_NONE, NULL));
     name = g_key_file_get_string (key_file, "Desktop Entry", "Name", NULL);
     g_assert_cmpstr (name, ==, test.name);
     g_free (name);
     exec = g_key_file_get_string (key_file, "Desktop Entry", "Exec", NULL);
-    g_assert (g_str_has_suffix (exec, test.url));
+    g_assert_true (g_str_has_suffix (exec, test.url));
     g_free (exec);
     g_assert_null (g_key_file_get_string (key_file, "Desktop Entry", "Icon", NULL));
     wm_class = g_key_file_get_string (key_file, "Desktop Entry", "StartupWMClass", NULL);
@@ -91,18 +91,18 @@ test_web_app_lifetime (void)
 
     /* test profile directory */
     profile_dir = ephy_web_application_get_profile_directory (id);
-    g_assert (g_str_has_prefix (desktop_file, profile_dir));
-    g_assert (g_str_has_prefix (profile_dir, ephy_dot_dir ()));
-    g_assert (g_file_test (profile_dir, G_FILE_TEST_EXISTS));
+    g_assert_true (g_str_has_prefix (desktop_file, profile_dir));
+    g_assert_true (g_str_has_prefix (profile_dir, ephy_profile_dir ()));
+    g_assert_true (g_file_test (profile_dir, G_FILE_TEST_EXISTS));
 
     /* Test proper symlink */
     basename = g_path_get_basename (desktop_file);
     desktop_link = g_build_filename (xdg_data_home, "applications", basename, NULL);
-    g_assert (g_file_test (desktop_link, G_FILE_TEST_EXISTS));
-    g_assert (g_file_test (desktop_link, G_FILE_TEST_IS_SYMLINK));
+    g_assert_true (g_file_test (desktop_link, G_FILE_TEST_EXISTS));
+    g_assert_true (g_file_test (desktop_link, G_FILE_TEST_IS_SYMLINK));
 
     /* Test exists API */
-    g_assert (ephy_web_application_exists (id));
+    g_assert_true (ephy_web_application_exists (id));
 
     /* Test list API */
     apps = ephy_web_application_get_application_list ();
@@ -119,12 +119,12 @@ test_web_app_lifetime (void)
 
     /* Test delete API */
     g_test_message ("DELETE: %s", test.name);
-    g_assert (ephy_web_application_delete (id));
+    g_assert_true (ephy_web_application_delete (id));
 
-    g_assert (g_file_test (desktop_link, G_FILE_TEST_EXISTS) == FALSE);
-    g_assert (g_file_test (desktop_link, G_FILE_TEST_IS_SYMLINK) == FALSE);
-    g_assert (g_file_test (profile_dir, G_FILE_TEST_EXISTS) == FALSE);
-    g_assert (ephy_web_application_exists (id) == FALSE);
+    g_assert_false (g_file_test (desktop_link, G_FILE_TEST_EXISTS));
+    g_assert_false (g_file_test (desktop_link, G_FILE_TEST_IS_SYMLINK));
+    g_assert_false (g_file_test (profile_dir, G_FILE_TEST_EXISTS));
+    g_assert_false (ephy_web_application_exists (id));
 
     apps = ephy_web_application_get_application_list ();
     g_assert_cmpint (g_list_length (apps), ==, 0);
@@ -151,7 +151,7 @@ main (int argc, char *argv[])
   /* Set $XDG_DATA_HOME to point to a directory inside our disposable
    * profile directory. This allows us to test cleanly and safely.
    * Note: $XDG_DATA_HOME default value is $HOME/.local/share/ */
-  xdg_data_home = g_build_filename (ephy_dot_dir (), "xdg_share", NULL);
+  xdg_data_home = g_build_filename (ephy_profile_dir (), "xdg_share", NULL);
   g_setenv ("XDG_DATA_HOME", xdg_data_home, TRUE);
 
   gtk_test_init (&argc, &argv);
